@@ -70,9 +70,8 @@ log.info("服务启动,完成规则引擎的初始化")
 
 # 加载Celery的框架东西
 # 获取远程配置中的配置项.判断是否有规则引擎相关的配置
-yml = Munch.fromDict(annotation.REMOTE_YML_CONFIG)
 try:
-    if yml.celery.enable:
+    if annotation.get_value("${celery.enable:false}"):
         import cloudcelery
         log.info("服务启动,完成celery的预启动")
 except:
@@ -123,9 +122,11 @@ class CeleryProcess(Process): #继承Process类
         self.name = name
 
     def run(self):
+        import uuid
         argv = [
             'worker',
             '--loglevel=INFO',
+            f'--hostname={config.actor_name}@{uuid.uuid4()}'
         ]
         import cloudcelery
         cloudcelery.celery.worker_main(argv)
